AlivcLiveBase class

Constructors

AlivcLiveBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getFlutterSdkVersion() → String
获取Flutter SDK版本号
getSdkVersion() → Future<String>
获取SDK版本号
registerSDK() → Future
注册SDK
setConsoleEnable(bool enable) → Future<void>
启用或禁用控制台日志打印
setListener(AlivcLiveBaseListener baseListener) → void
设置监听回调接口
setLogLevel(AlivcLivePushLogLevel level) → Future<void>
设置Log级别
setLogPath(String logPath, int maxPartFileSizeInKB) → Future<void>
设置Log路径

Constants

kFlutterVersion → const String
当前 Plugin 的版本号